@@ -2,8 +2,6 @@
 
 import logging
 
-import gobject
-
 import util.go_utils as gobject_utils
 import util.coroutines as coroutines
 import util.misc as misc_utils
@@ -294,7 +292,7 @@ class UpdateStateMachine(StateMachine):
 		self._reset_timers()
 
 	def _reset_timers(self, initialize=False):
-		if self._timeoutId is None:
+		if self._onTimeout.is_running():
 			return # not started yet
 		_moduleLogger.info("%s Resetting State Machine" % (self._name, ))
 		self._onTimeout.cancel()
